@@ -228,7 +228,7 @@ es-copy-index.pl - Copy an index from one cluster to another
 
 =head1 VERSION
 
-version 8.7
+version 8.8
 
 =head1 SYNOPSIS
 
@@ -405,7 +405,19 @@ The B<incident-rt1234-2013.01.11> index will now hold all the data from both of
 The search string is pre-analyzed before being sent to ElasticSearch.  The following plugins
 work to manipulate the query string and provide richer, more complete syntax for CLI applications.
 
-=head2 App::ElasticSearch::Utilities::QueryString::AutoEscape
+=head2 App::ElasticSearch::Utilities::QueryString::Barewords
+
+The following barewords are transformed:
+
+    or => OR
+    and => AND
+    not => NOT
+
+=head2 App::ElasticSearch::Utilities::QueryString::Text
+
+Provides field prefixes to manipulate the text search capabilities.
+
+=head3 Terms Query via '='
 
 Provide an '=' prefix to a query string parameter to promote that parameter to a C<term> filter.
 
@@ -423,15 +435,63 @@ Is translated into:
 
     { term => { user_agent => "Mozilla/5.0 (iPhone; CPU iPhone OS 12_1_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/12.0 Mobile/15E148 Safari/604.1" } }
 
-Which provides an exact match to the term in the query.
+=head3 Wildcard Query via '*'
 
-=head2 App::ElasticSearch::Utilities::QueryString::Barewords
+Provide an '*' prefix to a query string parameter to promote that parameter to a C<wildcard> filter.
 
-The following barewords are transformed:
+This uses the wild card match for text fields to making matching more intuitive.
 
-    or => OR
-    and => AND
-    not => NOT
+E.g.:
+
+    *user_agent:"Mozilla*"
+
+Is translated into:
+
+    { wildcard => { user_agent => "Mozilla* } }
+
+=head3 Regexp Query via '/'
+
+Provide an '/' prefix to a query string parameter to promote that parameter to a C<regexp> filter.
+
+If you want to use regexp matching for finding data, you can use:
+
+    /message:'\\bden(ial|ied|y)'
+
+Is translated into:
+
+    { regexp => { message => "\\bden(ial|ied|y)" } }
+
+=head3 Fuzzy Matching via '~'
+
+Provide an '~' prefix to a query string parameter to promote that parameter to a C<fuzzy> filter.
+
+    ~message:deny
+
+Is translated into:
+
+    { fuzzy => { message => "deny" } }
+
+=head3 Phrase Matching via '+'
+
+Provide an '+' prefix to a query string parameter to promote that parameter to a C<match_phrase> filter.
+
+    +message:"login denied"
+
+Is translated into:
+
+    { match_phrase => { message => "login denied" } }
+
+=head3 Automatic Match Queries for Text Fields
+
+If the field meta data is provided and the field is a C<text> type, the query
+will automatically be mapped to a C<match> query.
+
+    # message field is text
+    message:"foo"
+
+Is translated into:
+
+    { match => { message => "foo" } }
 
 =head2 App::ElasticSearch::Utilities::QueryString::IP
 
@@ -617,7 +677,7 @@ Brad Lhotsky <brad@divisionbyzero.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2023 by Brad Lhotsky.
+This software is Copyright (c) 2024 by Brad Lhotsky.
 
 This is free software, licensed under:
 
