@@ -196,8 +196,8 @@ pod2usage({-exitval=>1, -verbose=>0, -sections=>'SYNOPSIS', -msg=>'Cannot use --
     if exists $OPT{tail} && $OPT{sort};
 pod2usage({-exitval=>1, -verbose=>0, -sections=>'SYNOPSIS', -msg=>'Cannot use --sort along with --asc or --desc'})
     if $OPT{sort} && ($OPT{asc} || $OPT{desc});
-pod2usage({-exitval=>1, -verbose=>0, -sections=>'SYNOPSIS', -msg=>'Please specify --show with --tail'})
-    if exists $OPT{tail} && !@SHOW;
+pod2usage({-exitval=>1, -verbose=>0, -sections=>'SYNOPSIS', -msg=>'Please specify --show or --jq with --tail'})
+    if exists $OPT{tail} && !( @SHOW || $OPT{json});
 
 # Process extra parameters
 foreach my $presence ( qw( exists missing ) ) {
@@ -749,7 +749,7 @@ es-search.pl - Provides a CLI for quick searches of data in ElasticSearch daily
 
 =head1 VERSION
 
-version 8.7
+version 8.8
 
 =head1 SYNOPSIS
 
@@ -1135,7 +1135,19 @@ In the case of --top, this limits the result set to 1,000,000 results.
 The search string is pre-analyzed before being sent to ElasticSearch.  The following plugins
 work to manipulate the query string and provide richer, more complete syntax for CLI applications.
 
-=head2 App::ElasticSearch::Utilities::QueryString::AutoEscape
+=head2 App::ElasticSearch::Utilities::QueryString::Barewords
+
+The following barewords are transformed:
+
+    or => OR
+    and => AND
+    not => NOT
+
+=head2 App::ElasticSearch::Utilities::QueryString::Text
+
+Provides field prefixes to manipulate the text search capabilities.
+
+=head3 Terms Query via '='
 
 Provide an '=' prefix to a query string parameter to promote that parameter to a C<term> filter.
 
@@ -1153,15 +1165,63 @@ Is translated into:
 
     { term => { user_agent => "Mozilla/5.0 (iPhone; CPU iPhone OS 12_1_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/12.0 Mobile/15E148 Safari/604.1" } }
 
-Which provides an exact match to the term in the query.
+=head3 Wildcard Query via '*'
 
-=head2 App::ElasticSearch::Utilities::QueryString::Barewords
+Provide an '*' prefix to a query string parameter to promote that parameter to a C<wildcard> filter.
 
-The following barewords are transformed:
+This uses the wild card match for text fields to making matching more intuitive.
 
-    or => OR
-    and => AND
-    not => NOT
+E.g.:
+
+    *user_agent:"Mozilla*"
+
+Is translated into:
+
+    { wildcard => { user_agent => "Mozilla* } }
+
+=head3 Regexp Query via '/'
+
+Provide an '/' prefix to a query string parameter to promote that parameter to a C<regexp> filter.
+
+If you want to use regexp matching for finding data, you can use:
+
+    /message:'\\bden(ial|ied|y)'
+
+Is translated into:
+
+    { regexp => { message => "\\bden(ial|ied|y)" } }
+
+=head3 Fuzzy Matching via '~'
+
+Provide an '~' prefix to a query string parameter to promote that parameter to a C<fuzzy> filter.
+
+    ~message:deny
+
+Is translated into:
+
+    { fuzzy => { message => "deny" } }
+
+=head3 Phrase Matching via '+'
+
+Provide an '+' prefix to a query string parameter to promote that parameter to a C<match_phrase> filter.
+
+    +message:"login denied"
+
+Is translated into:
+
+    { match_phrase => { message => "login denied" } }
+
+=head3 Automatic Match Queries for Text Fields
+
+If the field meta data is provided and the field is a C<text> type, the query
+will automatically be mapped to a C<match> query.
+
+    # message field is text
+    message:"foo"
+
+Is translated into:
+
+    { match => { message => "foo" } }
 
 =head2 App::ElasticSearch::Utilities::QueryString::IP
 
@@ -1357,7 +1417,7 @@ Brad Lhotsky <brad@divisionbyzero.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2023 by Brad Lhotsky.
+This software is Copyright (c) 2024 by Brad Lhotsky.
 
 This is free software, licensed under:
 
